@@ -216,10 +216,10 @@ sub lookup_employee {
     if ( $key_spec =~ m/^emp/i ) {
         $status = send_req( 'GET', "employee/nick/$key$minimal" );
         BREAK_OUT: {
-            last BREAK_OUT if $status->not_ok and $status->{'http_code'} == 403;
-            if ( $status->not_ok and $status->{'http_code'} == 404 ) {
+            last BREAK_OUT if $status->not_ok and $status->payload and $status->payload->{'http_code'} == 403;
+            if ( $status->not_ok and $status->payload and $status->payload->{'http_code'} == 404 ) {
                 $status = send_req( 'GET', "employee/sec_id/$key$minimal" );
-                if ( $status->not_ok and $status->{'http_code'} != 500 and looks_like_number( $key ) ) {
+                if ( $status->not_ok and $status->payload and $status->payload->{'http_code'} != 500 and looks_like_number( $key ) ) {
                     $status = send_req( 'GET', "employee/eid/$key$minimal" );
                 }
             }
@@ -496,8 +496,10 @@ REST calls are cheap, so look up C<< $current_emp >> again just to make sure.
 
 sub refresh_current_emp {
     my $status = send_req( 'GET', 'employee/eid/' . $current_emp->eid );
-    $log->crit( "Problem with data integrity (current employee)" );
-    return $status unless $status->ok;
+    if ( $status->not_ok ) {
+        $log->crit( "Problem with data integrity (current employee)" );
+        return $status;
+    }
     $current_emp = App::Dochazka::Common::Model::Employee->spawn( %{ $status->payload } );
     return $status;
 }
